# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
import ntnx_dataprotection_py_client.models
from ntnx_dataprotection_py_client.models.OneOfvmm.v4.ahv.config.VmRestoreNicConfigOverrideParamsnic_backing_info import VmRestoreNicConfigOverrideParamsnic_backing_info  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.OneOfvmm.v4.ahv.config.VmRestoreNicConfigOverrideParamsnic_network_info import VmRestoreNicConfigOverrideParamsnic_network_info  # noqa: F401,E501

class VmRestoreNicConfigOverrideParams(object):

    """NIC configuration parameters that can be overridden when restoring the VM.

    :param nic_ext_id: (:attr:`nic_ext_id`) External identifier of the NIC being overridden from the VM Recovery Point. This is not preserved but is only relevant for mapping the NIC being overridden.
    :type nic_ext_id: required
    
    
    :param nic_backing_info: (:attr:`nic_backing_info`) Information about how NIC is associated with a VM.
    :type nic_backing_info: 
    
    
    :param nic_network_info: (:attr:`nic_network_info`) Networking information object for a NIC.
    :type nic_network_info: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'nic_ext_id': 'str',
        'nic_backing_info': 'OneOfvmm.v4.ahv.config.VmRestoreNicConfigOverrideParamsnic_backing_info',
        'nic_network_info': 'OneOfvmm.v4.ahv.config.VmRestoreNicConfigOverrideParamsnic_network_info',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'nic_ext_id': 'nicExtId',
        'nic_backing_info': 'nicBackingInfo',
        'nic_network_info': 'nicNetworkInfo',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, nic_ext_id=None, nic_backing_info=None, nic_network_info=None, *args, **kwargs):  # noqa: E501
        self.__nic_ext_id = None
        self.__nic_backing_info = None
        self.__nic_network_info = None
        self.discriminator = None
        self.__nic_ext_id = nic_ext_id
        if nic_backing_info is not None:
            self.__nic_backing_info = nic_backing_info
        if nic_network_info is not None:
            self.__nic_network_info = nic_network_info
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'vmm.v4.ahv.config.VmRestoreNicConfigOverrideParams'

    def _initialize_object_version(self):
        return 'v4.r1'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def nic_ext_id(self):
        """
        External identifier of the NIC being overridden from the VM Recovery Point. This is not preserved but is only relevant for mapping the NIC being overridden.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__nic_ext_id

    @nic_ext_id.setter
    def nic_ext_id(self, nic_ext_id):
        if nic_ext_id is None:
            raise ValueError("Invalid value for `nic_ext_id`, must not be `None`")  # noqa: E501
        if nic_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', nic_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `nic_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__nic_ext_id = nic_ext_id

    @property
    def nic_backing_info(self):
        """
        Information about how NIC is associated with a VM.

        :type:
                :class:`~ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.VmRestoreVirtualEthernetNicOverrideSpec`
        """  # noqa: E501
        return self.__nic_backing_info

    @nic_backing_info.setter
    def nic_backing_info(self, nic_backing_info):

        self.__nic_backing_info = nic_backing_info

    @property
    def nic_network_info(self):
        """
        Networking information object for a NIC.

        :type:
                :class:`~ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.VmRestoreVirtualEthernetNicNetworkInfoOverrideSpec`
        """  # noqa: E501
        return self.__nic_network_info

    @nic_network_info.setter
    def nic_network_info(self, nic_network_info):

        self.__nic_network_info = nic_network_info

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if attr_type.startswith('OneOf'):
                type = getattr(ntnx_dataprotection_py_client.models, attr_type.split('.')[-1])
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(VmRestoreNicConfigOverrideParams, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VmRestoreNicConfigOverrideParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

